;Some GUI functions
;Author: Shantanu Gadgil
;If you include this in your project,
;you will need to link against the following libs:
;kernel32, user32, gdi32
;- Enjoy!

.386
.model	flat, stdcall
option	casemap: none

include windows.inc

include kernel32.inc
include user32.inc
include gdi32.inc

.code
;UI_SetWindowLayered
; inputs: handle to window, boolean indicating to SET or UNSET
; the layered property of the window
UI_SetWindowLayered	proc	hWnd:HWND,bLayered:BOOL
	push	eax
	push	ebx
	
	invoke	GetWindowLong,hWnd,GWL_EXSTYLE
	.if	bLayered == TRUE
		or	eax,WS_EX_LAYERED
	.else
		mov	ebx,WS_EX_LAYERED
		not	ebx
		and	eax,ebx
	.endif
	invoke	SetWindowLong,hWnd,GWL_EXSTYLE,eax
	invoke	InvalidateRect,hWnd,NULL,TRUE
	
	pop	ebx
	pop	eax
	ret

UI_SetWindowLayered	endp

;UI_SetWindowTransparency
; inputs: handle to window, transparency level (0 to 100)
UI_SetWindowTransparency	proc	hWnd:HWND,dwLevel:DWORD
	push	eax
	push	ebx
	push	edx
	
	invoke	UI_SetWindowLayered,hWnd,TRUE
	
	xor	edx,edx
	mov	eax,dwLevel
	and	eax,0ffh
	mov	ebx,255
	mul	ebx
	xor	edx,edx
	mov	ebx,100
	div	ebx
	
	invoke	SetLayeredWindowAttributes,hWnd,0,eax,LWA_ALPHA
	
	pop	edx
	pop	ebx
	pop	eax
	ret

UI_SetWindowTransparency endp

;UI_GetControlRect
; inputs: handle to parent window, handle to the control, pointer to RECT
; The co-ordinates retrieved in the RECT are the co-ordinates of the control-window
; INSIDE the specified parent window
; Rationale: some kind of MoveWindow operation immediately after this call
UI_GetControlRect	proc	hWinParent:HWND, hWinControl:HWND, lprcRectangle:DWORD
	LOCAL	ptLocalControl:POINT
	LOCAL	rcLocalControl:RECT
	
	push	eax
	push	ebx
	
	invoke	GetWindowRect,hWinControl,addr rcLocalControl
	mov	eax,rcLocalControl.right
	sub	eax,rcLocalControl.left
	mov	ebx,lprcRectangle
	mov	RECT.right[ebx], eax	;WIDTH
	
	mov	eax,rcLocalControl.bottom
	sub	eax,rcLocalControl.top
	mov	ebx,lprcRectangle
	mov	RECT.bottom[ebx], eax	;HEIGHT

	push	rcLocalControl.left
	pop	ptLocalControl.x
	push	rcLocalControl.top
	pop	ptLocalControl.y
	
	invoke	ScreenToClient,hWinParent,addr ptLocalControl
	
	mov	ebx,lprcRectangle
	mov	eax,ptLocalControl.x
	mov	RECT.left[ebx], eax
	
	mov	eax,ptLocalControl.y
	mov	ebx,lprcRectangle
	mov	RECT.top[ebx], eax
	
	pop	ebx
	pop	eax
	ret
UI_GetControlRect endp

;UI_SetWindowStyle
;adds the SPECIFIED style to a window. Previous styles are maintained :)
UI_SetWindowStyle	proc	hWin:HWND, dwStyle:DWORD
	push	eax
	invoke	GetWindowLong,hWin,GWL_STYLE
	or	eax,dwStyle
	invoke	SetWindowLong,hWin,GWL_STYLE,eax
	pop	eax
	ret
UI_SetWindowStyle endp

;UI_RemoveWindowStyle
;removes ONLY the SPECIFIED style of a window
UI_RemoveWindowStyle	proc	hWin:HWND, dwStyle:DWORD
	push	eax
	push	ebx
	
	invoke	GetWindowLong,hWin,GWL_STYLE
	mov	ebx,dwStyle
	not	ebx
	and	eax,ebx
	invoke	SetWindowLong,hWin,GWL_STYLE,eax
	
	pop	ebx
	pop	eax
	ret
UI_RemoveWindowStyle endp

;UI_EnableDlgItem
;pretty self explanatory :) :)
UI_EnableDlgItem	proc	hWin:HWND, idCtl:SDWORD, fEnable:BOOL
	invoke	GetDlgItem,hWin,idCtl
	invoke	EnableWindow,eax,fEnable
	ret
UI_EnableDlgItem	endp

;UI_SetDlgItemFocus
;pretty self explanatory :) :)
UI_SetDlgItemFocus	proc	hWin:HWND, idCtl:SDWORD
	invoke	GetDlgItem,hWin,idCtl
	invoke	SetFocus,eax
	ret
UI_SetDlgItemFocus endp

end
